import QtQuick 2.2

Item {
    id:root
    anchors.fill: parent
    z:9998

    property bool appHasFocus: Qt.application.state==Qt.ApplicationActive && _myApp.appHasFocus
    property bool internetOn: ( _InternetOn=="true" || _InternetOn==true || _InternetOn==1 )
    property bool interstitialOn: interstitial.visible==true
    property bool adsOn: false

    property bool adBannerAvailable: false
    property bool adInterstitialAvailable: false

    onInternetOnChanged: {
        console.log("Internet ON: "+adManager.internetOn);
    }

    onAppHasFocusChanged: {
        console.debug("App Has Focus: "+appHasFocus)

        if(appHasFocus==true){
            adManager.showInterstitial();
        }
    }

    onAdsOnChanged: {
        if(adManager.adsOn==false){
            interstitial.visible=false;
            settings.setValue("adManager.adsOn","false");
        }
    }

    Connections{
        target: _myAdMob
        onAdInterstitialReceived:{
            root.adInterstitialAvailable = (value=="true") || value;
        }
        onAdBannerReceived:{
            root.adBannerAvailable = (value=="true") || value;
        }
    }

    Timer{
        interval: 1000
        running: true
        onTriggered: {
            /*Check if ads on*/

            if(settings.getValue("adManager.adsOn")=="false" || settings.getValue("adManager.adsOn")==0){
                adManager.adsOn=false;
            }
            else{
                adManager.adsOn= (_adsEnabled=="true");
                if(adManager.adsOn)_myAdMob.initAds();
            }
        }
    }

    function enableQuitAfterAd() {
        interstitial.quitAfter=true;
        _myAdMob.setQuitAfter();
    }

    function showInterstitial() {
//        console.log(interstitial.hasBeenShown +" "+adManager.internetOn+" "+adManager.adInterstitialAvailable);

        if(rateUsWindow.hasBeenShown == false && rateUsWindow.secondsPassedSinceInit>210 && rateUsWindow.numberOfViews<=3 && interstitial.quitAfter==false){
            rateUsWindow.visible=true;
        }
        else{
            if(adManager.adsOn==true){
                if(root.blockInterstitial==false || interstitial.quitAfter==true){
                    if(interstitial.hasBeenShown==false || adManager.internetOn==false || adManager.adInterstitialAvailable==false  ){
                        interstitial.visible=true;
                    }
                    else{
                        _myAdMob.showInterstitial();
                    }

                    root.blockInterstitial=true;
                    blockInterstitialTimer.restart();
                }
            }
            else{
                if(interstitial.quitAfter==true){
                    Qt.quit();
                }
            }
        }
    }

    property bool blockInterstitial:true
    Timer {
        id: blockInterstitialTimer
        interval: 1000*_interstitialAdInterval;
        running: true;
        onTriggered: {
            root.blockInterstitial=false;
        }
    }
}
