import QtQuick 2.2

Item{
    id:root
    property alias bgSource: bg.source
    property int timeOut: 0 //seconds
    property real timeStep: 0 // 0 - if no frames, 1.2.3 seconds otherwise
    property alias exitBoxVisible: exitBox.visible
    signal clicked

    anchors.fill: parent
    visible: false

    onVisibleChanged: {
        if(root.visible){
            xButtonTimer.start();
        }
        else{
            exitBox.visible=false;
        }
    }

    Rectangle{
        anchors.fill: parent
        color: "black"
        opacity: 0.75
    }

    AnimatedImage{
        id:bg
        anchors.centerIn: parent
        width: Math.min(screen.width,screen.height*1.2)*0.95
        height: screen.height*(screen.height>=screen.width?0.825:0.95)

        fillMode: Image.Stretch
        asynchronous: true
        currentFrame: 0
        smooth: true
    }

    Timer{
        id:animatedBgTimer
        running: root.timeStep!=0
        repeat: root.timeStep!=0
        interval: 1000*root.timeStep
        onTriggered: {
            bg.currentFrame=(bg.currentFrame+1);
            if(bg.currentFrame==bg.frameCount){
                animatedBgTimer.running=false;
                animatedBgTimer.repeat=false;
            }
        }
    }

    MouseArea{
        anchors.fill: parent
        onClicked: {
//            root.clicked();
        }
    }

    Rectangle{
        id:exitBox
        width: Math.max(root.width,root.height)*0.05
        height: width
        color: "transparent"
        radius: width/2
        visible: false

        border{
            color:"white"
            width:(screen.width+screen.height)/500
        }

        anchors{
            top: parent.top
            topMargin: Math.max(root.width,root.height)*0.0125
            right: parent.right
            rightMargin: Math.max(root.width,root.height)*0.0125
        }

        Text{
            id:exitLetter
            width:parent.width
            height:parent.height
            anchors{
                centerIn: parent
                verticalCenterOffset: -height*0.1
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            font{
                pixelSize: height*0.9
                family: mainFont.name
            }
            text:"x"
            color:"white"
        }
        MouseArea{
            anchors{
                fill: parent
                margins: -Math.max(parent.width,parent.height)
            }
            onClicked: {
                exitBox.visible=false;
                root.visible=false;
            }
        }
    }

    Timer{
        id:xButtonTimer
        interval: 100+1000*root.timeOut
        running: false
        onTriggered: {
            exitBox.visible=true;
        }
    }
}
