import QtQuick 2.2

Item {
    id:root

    signal clicked

    property url backgroundImageSource: ""
    property url inactiveBackgroundImageSource: ""
    property url highlightBackgroundImageSource: ""
    property alias symbolImageSource: symbolImage.source

    property bool active: true
    property alias pressed: mouseArea.pressed

    property bool sizeEffect: true
    property bool asynchronous: true


    property int size: 200
    property real symbolScale: 0.55

    width: size
    height: size

    Image {
        id: backgroundImage
        width:root.width;
        height:root.height;
        fillMode: Image.Stretch
        source: active?(pressed?root.highlightBackgroundImageSource:root.backgroundImageSource):root.inactiveBackgroundImageSource;
        asynchronous: root.asynchronous
        smooth: true
    }

    Image {
        id: symbolImage
        width:root.width*root.symbolScale;
        height:root.height*root.symbolScale;
        fillMode: Image.Stretch
        anchors{
            centerIn: parent
        }
        smooth: true
        asynchronous: root.asynchronous
    }

    MouseArea {
        id: mouseArea;
        anchors.fill: parent;
        anchors.margins: -root.size*0.2
        onClicked: {
            if(root.active==true){
                buttonSound.play();
                root.clicked();
            }
        }

        onPressed: {
            if(root.sizeEffect)
                scaleTimer.start();
        }

        onReleased: {
            root.scale=1;
        }
    }

    transformOrigin: Item.Center
    scale: 1

    Timer{
        id:scaleTimer
        repeat: root.pressed && root.sizeEffect
        running: false
        interval: 40
        onTriggered:{
            root.scale=Math.min(root.scale+0.03,1.15);
        }
    }
}
