import QtQuick 2.3
import QtQuick.Controls 1.2
import QtQuick.Window 2.0

ApplicationWindow{
    id:appLoader

    visible: true
    x:200
    y:100
    width: appLoader.isMobile?Screen.width:myComboBox.textAt(0).split("x")[0]
    height: appLoader.isMobile?Screen.height:myComboBox.textAt(0).split("x")[1]
    visibility: appLoader.isMobile?Window.FullScreen:Window.Windowed

    Component.onCompleted: {
        console.debug("MainWrapper started "+ new Date());
        appLoader.startDate=new Date();
    }

    property variant startDate

    BasicIntro{
        id: basicIntro
        width:parent.width
        height: parent.height
    }

    Loader{
        id:mainApp
        width:parent.width
        height: parent.height
        focus: true
//        asynchronous: true
        onLoaded:{
            basicIntro.opacity=0;
            if(_allowAnalytics=="true" || _allowAnalytics==true || _allowAnalytics==1 ){
                console.debug("MainAppLoaded "+ new Date());
                _myGoogleAnalytics.sendTimingEvent("MainAppLoaded",(new Date()).getTime()-appLoader.startDate.getTime(),"Time","ms");
            }
        }
    }

    Timer {
        id:appTimer
        interval: 100; running: true; repeat: true
        onTriggered: {
            mainApp.source="../main.qml";
            appTimer.running=false;
            console.debug("MainApp loaded"+ new Date()+width+" "+height);

        }
    }

    property bool isMobile: Qt.platform.os=="android" || Qt.platform.os=="ios" || Qt.platform.os=="blackberry"
                            || Qt.platform.os=="blackberry" || Qt.platform.os=="winrt" || Qt.platform.os=="winphone"

    function updateGeometry(){
        if(mainApp.status == Loader.Ready){
            var newHeight;
            var newWidth;
            if(portraitCheckBox.checked){
                newWidth=myComboBox.textAt(myComboBox.currentIndex).split("x")[0];
                newHeight=myComboBox.textAt(myComboBox.currentIndex).split("x")[1];
            }
            else{
                newWidth=myComboBox.textAt(myComboBox.currentIndex).split("x")[1];
                newHeight=myComboBox.textAt(myComboBox.currentIndex).split("x")[0];
            }

            if(newWidth>Screen.width*0.75 || newHeight>Screen.height*0.9 ){
                newWidth/=2;
                newHeight/=2;
            }
            if(newWidth>Screen.width*0.75 || newHeight>Screen.height*0.9 ){
                newWidth/=2;
                newHeight/=2;
            }
            appLoader.width=newWidth;
            appLoader.height=newHeight;
            console.log("NEW GEOMETRY: {"+appLoader.width+"x"+appLoader.height+"}.");
        }
    }

    ComboBox {
        id:myComboBox
        anchors{
            top:parent.top
            topMargin: Math.min(appLoader.width,appLoader.height)/100
            right: parent.right
            rightMargin: Math.min(appLoader.width,appLoader.height)/3
        }
        visible: appLoader.isMobile==false
        width: 60*Screen.width/1024;
        height: 15*Screen.height/768;
        model: [ "768x1280","720x1280","768x1024","480x854","1080x1920", "1200x1920","800x1280",
            "600x1024","750x1334","640x1136","540x960","720x720","1440x2560","1600x2560",
            "1440x1440","640x960","480x800","320x480","240x320" ]
        onCurrentIndexChanged: {
            appLoader.updateGeometry();
        }
    }

    CheckBox{
        id:portraitCheckBox
        anchors{
            top:myComboBox.bottom
            topMargin: myComboBox.anchors.topMargin
            right: parent.right
            rightMargin: myComboBox.anchors.rightMargin
        }
        visible: appLoader.isMobile==false
        height: 15*Screen.height/768;
        width: height
        checked: true
        onCheckedChanged: {
            appLoader.updateGeometry();
        }
    }
}
